@@ -29,7 +29,7 @@ class BasicResBlock(nn.Module):
 
         out = self.conv1(out)
         out = self.bn1(out)
-        out = out + x  
+        #out = out + x  #Can be used to provide extra shortcut inside ResBlock itself
 
         out = F.relu(out)
 
