@@ -478,7 +478,6 @@ class LRFinder(object):
         axis[0].set_xlabel('Learning Rate')
         axis[0].set_ylabel('Loss')
         axis[0].set_title('Range Test - LR vs Loss')
-        axis[0].axvline(x= self.lr_for_minloss, color= 'red')
         if log_lr:
             axis[0].set_xscale('log')
 
@@ -486,7 +485,6 @@ class LRFinder(object):
         axis[1].set_xlabel('Learning Rate')
         axis[1].set_ylabel('Accuracy')
         axis[1].set_title('Range Test - LR vs Accuracy')
-        axis[1].axvline(x= self.lr_for_maxacc, color= 'red')
         if log_lr:
             axis[1].set_xscale('log')
 
